BinaryOp class final

Binary operator application, e.g. a + b or x == y.

Inheritance

Constructors

BinaryOp(String op, LamExpr left, LamExpr right)
Creates a binary operation.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
left LamExpr
The left operand.
final
op String
The operator.
final
The right operand.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited