Pipe class final

Pipeline expression: expr | expr.

Evaluates op with the result of input as context. This is expression composition: the right side sees . bound to the left side's result.

Inheritance

Constructors

Pipe(LamExpr input, LamExpr op)
Creates a pipeline of input through op.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
input LamExpr
The input expression.
final
op LamExpr
The expression to evaluate with the input's result as context.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited