Pipe class final
Pipeline expression: expr | expr.
Evaluates op with the result of input as context. This is expression
composition: the right side sees . bound to the left side's result.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited