ShapeRequirement class sealed
The shape a given OutputFormat requires at its root.
Sealed hierarchy with concrete subclasses AnyShape, MustBeMap, and MustBeList.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
accepts(
Shape shape) → bool -
Whether
shapesatisfies this requirement. -
describe(
) → String - Human-readable description of the requirement, suitable for error messages.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited